Index: third_party/zlib/inftrees.h |
=================================================================== |
--- third_party/zlib/inftrees.h (revision 113739) |
+++ third_party/zlib/inftrees.h (working copy) |
@@ -1,5 +1,5 @@ |
/* inftrees.h -- header to use inftrees.c |
- * Copyright (C) 1995-2005 Mark Adler |
+ * Copyright (C) 1995-2005, 2010 Mark Adler |
* For conditions of distribution and use, see copyright notice in zlib.h |
*/ |
@@ -35,21 +35,28 @@ |
01000000 - invalid code |
*/ |
-/* Maximum size of dynamic tree. The maximum found in a long but non- |
- exhaustive search was 1444 code structures (852 for length/literals |
- and 592 for distances, the latter actually the result of an |
- exhaustive search). The true maximum is not known, but the value |
- below is more than safe. */ |
-#define ENOUGH 2048 |
-#define MAXD 592 |
+/* Maximum size of the dynamic table. The maximum number of code structures is |
+ 1444, which is the sum of 852 for literal/length codes and 592 for distance |
+ codes. These values were found by exhaustive searches using the program |
+ examples/enough.c found in the zlib distribtution. The arguments to that |
+ program are the number of symbols, the initial root table size, and the |
+ maximum bit length of a code. "enough 286 9 15" for literal/length codes |
+ returns returns 852, and "enough 30 6 15" for distance codes returns 592. |
+ The initial root table size (9 or 6) is found in the fifth argument of the |
+ inflate_table() calls in inflate.c and infback.c. If the root table size is |
+ changed, then these maximum sizes would be need to be recalculated and |
+ updated. */ |
+#define ENOUGH_LENS 852 |
+#define ENOUGH_DISTS 592 |
+#define ENOUGH (ENOUGH_LENS+ENOUGH_DISTS) |
-/* Type of code to build for inftable() */ |
+/* Type of code to build for inflate_table() */ |
typedef enum { |
CODES, |
LENS, |
DISTS |
} codetype; |
-extern int inflate_table OF((codetype type, unsigned short FAR *lens, |
+int ZLIB_INTERNAL inflate_table OF((codetype type, unsigned short FAR *lens, |
unsigned codes, code FAR * FAR *table, |
unsigned FAR *bits, unsigned short FAR *work)); |